#include "Utility.hpp"
#include "Wormhole.hpp"

Wormhole::Wormhole(): _light(std::make_shared<ltbl::LightPointEmission>())
{
	_light->_emissionSprite.setColor(sf::Color::White);
	_light->_localCastCenter = sf::Vector2f(0.0f, 0.0f);
}

void Wormhole::load(const sf::Texture& texture1, const sf::Texture& texture2)
{
	_sprite.setTexture(texture1);
	_sprite.setOrigin(sf::Vector2f(texture1.getSize() / 2u));
	
	_light->_emissionSprite.setTexture(texture2);
	_light->_emissionSprite.setOrigin(sf::Vector2f(texture2.getSize() / 2u));
}

Wormhole::~Wormhole()
{
	Echo::debug("Deleting a wormhole.");
}

void Wormhole::update(sf::Time delta)
{
	float degree = delta.asSeconds() * 36.f;
	_sprite.rotate(degree);
	_light->_emissionSprite.rotate(degree);
}

void Wormhole::setPosition(sf::Vector2f position)
{
	_sprite.setPosition(position);
	_light->_emissionSprite.setPosition(position);
}

void Wormhole::setPosition(float x, float y)
{
	setPosition(sf::Vector2f(x, y));
}

std::shared_ptr<ltbl::LightPointEmission>& Wormhole::light()
{
	return _light;
}

void Wormhole::draw(sf::RenderTarget& target, sf::RenderStates states) const
{
	target.draw(_sprite);
}

